@@ -23,8 +23,31 @@ class Client():
 
         self.lb_client = labelboxClient(lb_api_key, endpoint=lb_endpoint, enable_experimental=lb_enable_experimental, app_url=lb_app_url)
            
-    # def create_table_from_dataset(): 
-    #     return table 
+    def export_to_table(
+        self, project, 
+        include_metadata:bool=False, include_performance:bool=False, include_agreement:bool=False,
+        verbose:bool=False, divider="///"):
+        """ Creates a Pandas DataFrame given a Labelbox Projet ID
+        Args:
+            project                 :   Required (str / lablebox.Project) - Labelbox Project ID or lablebox.Project object to export labels from
+            include_metadata        :   Optional (bool) - If included, exports metadata fields
+            include_performance     :   Optional (bool) - If included, exports labeling performance
+            include_agreement       :   Optional (bool) - If included, exports consensus scores       
+            verbose                 :   Optional (bool) - If True, prints details about code execution; if False, prints minimal information
+            divider                 :   Optional (str) - String delimiter for schema name keys and suffix added to duplocate global keys 
+        """
+        flattened_labels_dict = labelbase.downloader.export_and_flatten_labels(
+            client=self.lb_client, project=project, 
+            include_metadata=include_metadata, include_performance=include_performance, include_agreement=include_agreement,
+            verbose=verbose, divider=divider
+        )
+        
+        table = pd.DataFrame.from_dict(flattened_labels_dict)
+        
+        if verbose:
+            print(f"Success: DataFrame generated")
+        
+        return table 
 
     def create_data_rows_from_table(
         self, table:pd.core.frame.DataFrame, dataset_id:str="", project_id:str="", priority:int=5, 
@@ -39,7 +62,7 @@ class Client():
             skip_duplicates     :   Optional (bool) - Determines how to handle if a global key to-be-uploaded is already in use
                                         If True, will skip duplicate global_keys and not upload them
                                         If False, will generate a unique global_key with a suffix {divider} + "1", "2" and so on
-            verbose             :   Required (bool) - If True, prints details about code execution; if False, prints minimal information
+            verbose             :   Optional (bool) - If True, prints details about code execution; if False, prints minimal information
             divider             :   Optional (str) - String delimiter for schema name keys and suffix added to duplocate global keys
         """
         # Create a metadata_index, attachment_index, and annotation_index
@@ -90,6 +113,8 @@ class Client():
             metadata_index=metadata_index, attachment_index=attachment_index, annotation_index=annotation_index,
             upload_method=upload_method, divider=divider, verbose=verbose
         )      
+        
+        print(upload_dict)
                 
         # Upload your data rows to Labelbox - update upload_dict if global keys are modified during upload
         data_row_upload_results, upload_dict = labelbase.uploader.batch_create_data_rows(
