@@ -83,13 +83,14 @@ def create_upload_dict(client:labelboxClient, table: pandas.core.frame.DataFrame
     else:
         project_ids = []
     project_id_to_ontology_index = {}
-    if (project_ids!=[]) and (atachment_index!={}) and (upload_method in ["mal", "import"]): # If we're uploading annotations
+    if (project_ids!=[]) and (annotation_index!={}) and (upload_method in ["mal", "import"]): # If we're uploading annotations
         for projectId in project_ids:
             ontology_index = labelbase.ontology.get_ontology_schema_to_name_path(
                 ontology=client.get_project(projectId).ontology(), 
                 divider=divider, invert=True, detailed=True
             )
             project_id_to_ontology_index[projectId] = ontology_index
+    print(project_id_to_ontology_index)
     # Initiate your upload dict, where they keys are all your dataset IDs
     if dataset_id:
         upload_dict = {dataset_id : {}}
